@@ -1,7 +1,7 @@
 package Protocol::HTTP2::Frame::Ping;
 use strict;
 use warnings;
-use Protocol::HTTP2::Constants qw(:flags :errors);
+use Protocol::HTTP2::Constants qw(:flags :errors :limits);
 use Protocol::HTTP2::Trace qw(tracer);
 
 sub decode {
@@ -9,18 +9,17 @@ sub decode {
     my $frame_ref = $con->decode_context->{frame};
 
     # PING associated with connection
-    if (
-        $frame_ref->{stream} != 0
-        ||
-
-        # payload is 8 octets
-        $length != 8
-      )
-    {
+    if ( $frame_ref->{stream} != 0 ) {
         $con->error(PROTOCOL_ERROR);
         return undef;
     }
 
+    # payload is 8 octets
+    if ( $length != PING_PAYLOAD_SIZE ) {
+        $con->error(FRAME_SIZE_ERROR);
+        return undef;
+    }
+
     $con->ack_ping( \substr $$buf_ref, $buf_offset, $length )
       unless $frame_ref->{flags} & ACK;
 
@@ -29,7 +28,7 @@ sub decode {
 
 sub encode {
     my ( $con, $flags_ref, $stream, $data_ref ) = @_;
-    if ( length($$data_ref) != 8 ) {
+    if ( length($$data_ref) != PING_PAYLOAD_SIZE ) {
         $con->error(INTERNAL_ERROR);
         return undef;
     }
